(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports);
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports);
        global.utils = mod.exports;
    }
})(this, function (exports) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });
    var hasDocument = typeof document !== 'undefined';
    var vendorEvents = [{
        hidden: 'hidden',
        event: 'visibilitychange',
        state: 'visibilityState'
    }, {
        hidden: 'webkitHidden',
        event: 'webkitvisibilitychange',
        state: 'webkitVisibilityState'
    }, {
        hidden: 'mozHidden',
        event: 'mozvisibilitychange',
        state: 'mozVisibilityState'
    }, {
        hidden: 'msHidden',
        event: 'msvisibilitychange',
        state: 'msVisibilityState'
    }, {
        hidden: 'oHidden',
        event: 'ovisibilitychange',
        state: 'oVisibilityState'
    }];

    var isSupported = exports.isSupported = hasDocument && Boolean(document.addEventListener);

    var visibility = exports.visibility = function () {
        if (!isSupported) {
            return null;
        }
        var _iteratorNormalCompletion = true;
        var _didIteratorError = false;
        var _iteratorError = undefined;

        try {
            for (var _iterator = vendorEvents[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                var event = _step.value;

                if (event.hidden in document) {
                    return event;
                }
            }
            // otherwise it's not supported
        } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
        } finally {
            try {
                if (!_iteratorNormalCompletion && _iterator.return) {
                    _iterator.return();
                }
            } finally {
                if (_didIteratorError) {
                    throw _iteratorError;
                }
            }
        }

        return null;
    }();

    var getHandlerArgs = exports.getHandlerArgs = function getHandlerArgs() {
        if (!visibility) {
            return [true, 'visible'];
        }
        var hidden = visibility.hidden,
            state = visibility.state;

        return [!document[hidden], document[state]];
    };
});